@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 import os
 import sys
 
@@ -11,3 +9,6 @@ master_doc = 'index'
 apidoc_module_dir = '.'
 apidoc_excluded_paths = ['conf.py']
 apidoc_separate_modules = True
+apidoc_toc_file = 'custom'
+apidoc_module_first = True
+apidoc_extra_args = ['--private']
