@@ -1,12 +1,11 @@
-# -*- coding: utf-8 -*-
 """
-    test_apidoc
-    ~~~~~~~~~~~
+test_apidoc
+~~~~~~~~~~~
 
-    Test the sphinxcontrib.apidoc module.
+Test the sphinxcontrib.apidoc module.
 
-    :copyright: Copyright 2018 by Stephen Finucane <stephen@that.guru>.
-    :license: BSD, see LICENSE for details.
+:copyright: Copyright 2018-present by Stephen Finucane <stephen@that.guru>
+:license: BSD, see LICENSE for details.
 """
 
 import pytest
@@ -14,17 +13,24 @@ import sphinx
 from sphinx.util import logging
 
 
+def is_dir(path):
+    if sphinx.version_info >= (7, 2, 0):
+        return path.is_dir()
+    else:
+        return path.isdir()
+
+
 @pytest.mark.sphinx('html', testroot='basics')
 def test_basics(app, status, warning):
     logging.setup(app, status, warning)
     app.builder.build_all()
 
-    assert (app.srcdir / 'api').isdir()
+    assert is_dir(app.srcdir / 'api')
     assert (app.srcdir / 'api' / 'modules.rst').exists()
     assert (app.srcdir / 'api' / 'apidoc_dummy_module.rst').exists()
     assert not (app.srcdir / 'api' / 'conf.rst').exists()
 
-    assert (app.outdir / 'api').isdir()
+    assert is_dir(app.outdir / 'api')
     assert (app.outdir / 'api' / 'modules.html').exists()
     assert (app.outdir / 'api' / 'apidoc_dummy_module.html').exists()
     assert not (app.outdir / 'api' / 'conf.html').exists()
@@ -40,13 +46,13 @@ def test_advanced(app, status, warning):
     logging.setup(app, status, warning)
     app.builder.build_all()
 
-    assert (app.srcdir / 'api').isdir()
+    assert is_dir(app.srcdir / 'api')
     assert (app.srcdir / 'api' / 'custom.rst').exists()
     for module in [
-            'apidoc_dummy_module.rst',
-            'apidoc_dummy_package.apidoc_dummy_submodule_a.rst',
-            'apidoc_dummy_package.apidoc_dummy_submodule_b.rst',
-            'apidoc_dummy_package._apidoc_private_dummy_submodule.rst',
+        'apidoc_dummy_module.rst',
+        'apidoc_dummy_package.apidoc_dummy_submodule_a.rst',
+        'apidoc_dummy_package.apidoc_dummy_submodule_b.rst',
+        'apidoc_dummy_package._apidoc_private_dummy_submodule.rst',
     ]:
         assert (app.srcdir / 'api' / module).exists()
     assert (app.srcdir / 'api' / 'apidoc_dummy_package.rst').exists()
@@ -58,13 +64,13 @@ def test_advanced(app, status, warning):
     # The 'Module contents' header isn't present if '--module-first' used
     assert 'Module contents' not in package_doc
 
-    assert (app.outdir / 'api').isdir()
+    assert is_dir(app.outdir / 'api')
     assert (app.outdir / 'api' / 'custom.html').exists()
     for module in [
-            'apidoc_dummy_module.html',
-            'apidoc_dummy_package.apidoc_dummy_submodule_a.html',
-            'apidoc_dummy_package.apidoc_dummy_submodule_b.html',
-            'apidoc_dummy_package._apidoc_private_dummy_submodule.html',
+        'apidoc_dummy_module.html',
+        'apidoc_dummy_package.apidoc_dummy_submodule_a.html',
+        'apidoc_dummy_package.apidoc_dummy_submodule_b.html',
+        'apidoc_dummy_package._apidoc_private_dummy_submodule.html',
     ]:
         assert (app.outdir / 'api' / module).exists()
     assert (app.outdir / 'api' / 'apidoc_dummy_package.html').exists()
@@ -79,9 +85,9 @@ def test_advanced_negative(app, status, warning):
     logging.setup(app, status, warning)
     app.builder.build_all()
 
-    assert (app.srcdir / 'api').isdir()
+    assert is_dir(app.srcdir / 'api')
     for module in [
-            'apidoc_dummy_module.rst',
+        'apidoc_dummy_module.rst',
     ]:
         assert (app.srcdir / 'api' / module).exists()
     assert (app.srcdir / 'api' / 'apidoc_dummy_package.rst').exists()
@@ -94,9 +100,9 @@ def test_advanced_negative(app, status, warning):
     # The 'Module contents' header is present if '--module-first' isn't used
     assert 'Module contents' in package_doc
 
-    assert (app.outdir / 'api').isdir()
+    assert is_dir(app.outdir / 'api')
     for module in [
-            'apidoc_dummy_module.html',
+        'apidoc_dummy_module.html',
     ]:
         assert (app.outdir / 'api' / module).exists()
     assert (app.outdir / 'api' / 'apidoc_dummy_package.html').exists()
